summaryrefslogtreecommitdiff
path: root/gcc/expr.h
diff options
context:
space:
mode:
authorwehle <wehle@138bc75d-0d04-0410-961f-82ee72b054a4>2000-02-18 06:32:01 +0000
committerwehle <wehle@138bc75d-0d04-0410-961f-82ee72b054a4>2000-02-18 06:32:01 +0000
commitff27bca2adce6ae5da74aee3aac56120b03e8b94 (patch)
tree3c30c190987a1ec418bb165199041649c8b305e1 /gcc/expr.h
parent95e14b59db4e9ee95e5e0e14e0f4e508f4ff04d3 (diff)
downloadgcc-ff27bca2adce6ae5da74aee3aac56120b03e8b94.tar.gz
* loop.c (canonicalize_condition): New function,
broken out of get_condition. (get_condition): Use it. * expr.h (canonicalize_condition): Prototype it. * tree.h (tree_int_cst_msb): Declare. * tree.c (tree_int_cst_msb): New function. git-svn-id: svn+ssh://gcc.gnu.org/svn/gcc/trunk@32045 138bc75d-0d04-0410-961f-82ee72b054a4
Diffstat (limited to 'gcc/expr.h')
-rw-r--r--gcc/expr.h7
1 files changed, 6 insertions, 1 deletions
diff --git a/gcc/expr.h b/gcc/expr.h
index ef8622a620d..22af908908f 100644
--- a/gcc/expr.h
+++ b/gcc/expr.h
@@ -888,7 +888,12 @@ extern rtx emit_store_flag_force PARAMS ((rtx, enum rtx_code, rtx, rtx,
/* Functions from loop.c: */
-/* Given a JUMP_INSN, return a description of the test being made. */
+/* Given an insn and condition, return a canonical description of
+ the test being made. */
+extern rtx canonicalize_condition PARAMS ((rtx, rtx, int, rtx *));
+
+/* Given a JUMP_INSN, return a canonical description of the test
+ being made. */
extern rtx get_condition PARAMS ((rtx, rtx *));
/* Generate a conditional trap instruction. */